@@ -255,11 +255,11 @@ class WebDAVBackend(duplicity.backend.Backend):
             try:
                 return self.get_kerberos_authorization()
             except ImportError:
-                log.warn(_("python-kerberos needed to use kerberos \
+                log.Warn(_("python-kerberos needed to use kerberos \
                           authorization, falling back to basic auth."))
                 return self.get_basic_authorization()
             except Exception as e:
-                log.warn(_("Kerberos authorization failed: %s.\
+                log.Warn(_("Kerberos authorization failed: %s.\
                           Falling back to basic auth.") % e)
                 return self.get_basic_authorization()
         elif token.lower() == 'basic':
@@ -272,7 +272,7 @@ class WebDAVBackend(duplicity.backend.Backend):
         return urllib2.parse_keqv_list(urllib2.parse_http_list(challenge_string))
 
     def get_kerberos_authorization(self):
-        import kerberos
+        import kerberos  # pylint: disable=import-error
         _, ctx = kerberos.authGSSClientInit("HTTP@%s" % self.conn.host)
         kerberos.authGSSClientStep(ctx, "")
         tgt = kerberos.authGSSClientResponse(ctx)
@@ -283,7 +283,7 @@ class WebDAVBackend(duplicity.backend.Backend):
         Returns the basic auth header
         """
         auth_string = '%s:%s' % (self.username, self.password)
-        return 'Basic %s' % base64.encodestring(auth_string).strip()
+        return 'Basic %s' % "".join(base64.encodestring(auth_string).split())
 
     def get_digest_authorization(self, path):
         """
